#' Rotates a point (x,y) by an angle
#'
#' \code{rotate} calculates the coordinates for a point (x,y) after it rotates by a angle theta (radian)
#' @param xy A vector of length 2 representing the coordinates of a point in cartesian system
#' @param theta A number rotating angle in radian
#' @return Coordinates of the point after the rotation
#' @examples
#' rotate(c(0, 1000), theta=.5)
#' @export
rotate <- function(xy, theta = 0) {
    if (getOption("warn") > 0) {
        stopifnot(is.numeric(xy), length(xy) == 2)
    }
    nx <- sum(c(cos(theta), -sin(theta)) * xy)
    ny <- sum(c(sin(theta),  cos(theta)) * xy)
    return(c(nx, ny))
}
